@@ -4,6 +4,10 @@ from mindsdb_native.libs.data_types.data_source import DataSource
 
 
 class MSSQLDS(DataSource):
+    def __init__(self, *args, **kwargs):
+        self.is_sql = True
+        super(MSSQLDS, self).__init__(*args, **kwargs)
+
     def _setup(self, table=None, query=None, database='master', host='localhost',
                port=1433, user='sa', password=''):
 
@@ -18,7 +22,7 @@ class MSSQLDS(DataSource):
                            password=password,
                            database=database) as con:
             df = pd.read_sql(query, con=con)
-            
+
         col_map = {}
         for col in df.columns:
             col_map[col] = col
@@ -30,4 +34,4 @@ class MSSQLDS(DataSource):
             self.__class__.__name__,
             self._database_name,
             self._table_name
-        )
\ No newline at end of file
+        )
