@@ -5,6 +5,10 @@ from mindsdb_native.libs.data_types.data_source import DataSource
 
 
 class MySqlDS(DataSource):
+    def __init__(self, *args, **kwargs):
+        self.is_sql = True
+        super(MySqlDS, self).__init__(*args, **kwargs)
+
     def _setup(self, table=None, query=None, database='mysql', host='localhost',
                port=3306, user='root', password=''):
 
@@ -34,4 +38,4 @@ class MySqlDS(DataSource):
         return '{}: {}'.format(
             self.__class__.__name__,
             self._database_name
-        )
\ No newline at end of file
+        )
